/*****************************************************************************
 * file.c
 *
 * bc-cat module unit test - BC_MEMORY_MMAP feature
 *
 * Copyright (C) 2009 Texas Instruments Incorporated - http://www.ti.com/
 *
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *   
 *   Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the
 *   distribution.
 *   
 *   Neither the name of Texas Instruments Incorporated nor the names of
 *   its contributors may be used to endorse or promote products derived
 *   from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#include <stdio.h>
#include <stdlib.h>     /*malloc() & free()*/
#include <img_defs.h>
#include <servicesext.h>
#include <bc_cat.h>

#define FRAME_WIDTH     128
#define FRAME_HEIGHT    128
#define FRAME_SIZE      (FRAME_WIDTH * FRAME_HEIGHT * 2)
#define MAX_FRAMES      1
#define YUV_PIXEL_FMT   PVRSRV_PIXEL_FORMAT_FOURCC_ORG_UYVY

void pattern_uyvy(void *p, int w, int h);

static char *frame[MAX_FRAMES];
static char *yuv_data = NULL;
static int   fr_idx = 0;

int frame_init(bc_buf_params_t *p)
{
    int   ii;

    yuv_data = malloc(FRAME_SIZE * MAX_FRAMES);
    if (yuv_data == NULL) {
        fprintf(stdout, "no enough memory for input file\n");
        return -1;
    }

    for (ii = 0; ii < MAX_FRAMES; ii++) {
        frame[ii] = &yuv_data[ii * FRAME_SIZE];
    }

    if (p) {
        p->count = MAX_FRAMES;
        p->width = FRAME_WIDTH;
        p->height = FRAME_HEIGHT;
        p->pixel_fmt = YUV_PIXEL_FMT;
        p->type = BC_MEMORY_MMAP;      
    }

    return 0;
}

char *frame_get(bc_buf_ptr_t *p)
{
    char *va;
    va = frame[fr_idx];
    pattern_uyvy(va, FRAME_WIDTH, FRAME_HEIGHT);
    fr_idx = (fr_idx + 1) % MAX_FRAMES;

    if (p)
        p->pa = 0;

    return va;
}

int frame_restore(char *p)
{
    p = p;
    return 0;
}

void frame_cleanup(void)
{
    if (yuv_data)
        free(yuv_data);
}
